<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>Achtung</translation>
    </message>
    <message>
        <source>Unable to launch external application.</source>
        <translation>Fehler beim Starten der externen Anwendung.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>Beim Registrieren der Dokumentationsdatei &apos;%1&apos; trat ein Fehler auf: %2</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>Dokumentationsdatei %1 kann nicht registriert werden

Grund:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>Dokumentation erfolgreich registriert.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>Registrierung der Dokumentationsdatei %1 kann nicht aufgehoben werden

Grund:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>Dokumentation erfolgreich entfernt.</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>Fehler beim Lesen der Katalogdatei &apos;%1&apos;: %2.</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>Fehler beim Erstellen der Katalogdatei &apos;%1&apos;: %2.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Der Datenbanktreiber für SQLite kann nicht geladen werden.</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>Lesezeichen:</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>Erstellen in:</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Ordner umbenennen</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Ohne Titel</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Untitled</source>
        <translation>Ohne Titel</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>Wenn Sie diesen Ordner löschen, wird auch&lt;br&gt;dessen kompletter Inhalt gelöscht. Möchten Sie wirklich fortfahren?</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Lesezeichen verwalten...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Lesezeichen hinzufügen ...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Ordner löschen</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Ordner umbenennen</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Lesezeichen öffnen</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Lesezeichen in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Lesezeichen löschen</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Lesezeichen umbenennen</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Lesezeichen verwalten</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Suche:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>Importieren und Sichern</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>Importieren...</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>Exportieren...</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>Dateien (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>Die Lesezeichen konnten nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>Beim Löschen des Ordners wird auch dessen Inhalt entfernt.&lt;br&gt;Möchten Sie fortsetzen?</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Ordner löschen</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Ordner umbenennen</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Lesezeichen anzeigen</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Lesezeichen in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Lesezeichen löschen</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Lesezeichen umbenennen</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Bookmarks Toolbar</source>
        <translation>Lesezeichenleiste</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Lesezeichen-Menü</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Print Document</source>
        <translation>Drucken</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Unknown option: %1</source>
        <translation>Unbekannte Option: %1</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>Unbekanntes Widget-Objekt: %1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>Die Katalogdatei &apos;%1&apos; existiert nicht.</translation>
    </message>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Obsolete. Use -remove-search-index instead.
                           Removes the full text search index.
                           It will be rebuilt on next Assistant run.
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Obsolete. Use -remove-search-index instead.
                           Removes the full text search index.
                           It will be rebuilt on next Assistant run.
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>Fehlende Katalogdatei.</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>Ungültige URL &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>Fehlende URL.</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>Fehlendes Widget-Objekt.</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Die Hilfedatei &apos;%1&apos; existiert nicht.</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>Fehlende Hilfedatei.</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>Das Filter-Argument fehlt.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Hinweis</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>Link öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>Voriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Groß/Kleinschreibung beachten</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Seitenende erreicht</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>S&amp;kript</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>&amp;Schriftart</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>S&amp;chriftschnitt</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>&amp;Schriftgrad</translation>
    </message>
</context>
<context>
    <name>GlobalActions</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Rückwärts</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Vorwärts</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Startseite</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>ALT+Home</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>&amp;Vergrößern</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>Ausgewählten Text &amp;kopieren</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Drucken ...</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>&amp;Textsuche ...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suchen</translation>
    </message>
</context>
<context>
    <name>HelpDocSettingsWidget</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Registered Documentation</source>
        <translation>Registrierte Dokumentationen</translation>
    </message>
    <message>
        <source>&lt;Filter&gt;</source>
        <translation>&lt;Filter&gt;</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Hinzufügen...</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
</context>
<context>
    <name>HelpDocSettingsWidgetPrivate</name>
    <message>
        <source>Add Documentation</source>
        <translation>Dokumentation hinzufügen</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Komprimierte Qt-Hilfedateien (*.qch)</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation>&lt;title&gt;about:blank&lt;/title&gt;</translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;Fehler 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;Die Seite kann nicht gefunden werden.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Link öffnen</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>&amp;Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>Link in neuem Reiter öffnen (Strg + linke Maustaste)</translation>
    </message>
    <message>
        <source>Error 404...</source>
        <translation>Fehler 404...</translation>
    </message>
    <message>
        <source>The page could not be found</source>
        <translation>Die Seite konnte nicht gefunden werden</translation>
    </message>
    <message>
        <source>Please make sure that you have all documentation sets installed.</source>
        <translation>Bitte stellen Sie sicher, dass alle Dokumentationssätze installiert sind.</translation>
    </message>
    <message>
        <source>Error loading: %1</source>
        <translation>Fehler beim Laden von %1</translation>
    </message>
    <message>
        <source>Open Link in New Page</source>
        <translation>Link in neuer Seite öffnen</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>Suchen &amp;nach:</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Link öffnen</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Inhalt</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Lesezeichen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>S&amp;eite einrichten ...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>Druckvorschau ...</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Neuer &amp;Reiter</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Reiter &amp;schließen</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>&amp;Weitersuchen</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>&amp;Vorheriges suchen</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Einstellungen ...</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>Standard&amp;größe</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>Seite mit Inhaltsangabe abgleichen</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Nächste Seite</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Right</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Vorherige Seite</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Left</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</source>
        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Unfiltered</source>
        <translation>Ungefiltert</translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>Die Datei &apos;%1&apos; konnte nicht registriert werden: %2</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>Über ...</translation>
    </message>
    <message>
        <source>Open Pages</source>
        <translation>Offene Seiten</translation>
    </message>
    <message>
        <source>Bookmark Toolbar</source>
        <translation>Lesezeichen-Leiste</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>B&amp;eenden</translation>
    </message>
    <message>
        <source>ALT+P</source>
        <translation>ALT+P</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>Navigationsleiste</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Werkzeugleisten</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>Filterleiste</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>Adressleiste</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adresse:</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>Der zugehörige Inhaltseintrag konnte nicht gefunden werden.</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>Suchindex wird aufgebaut</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>Suche nach Qt-Dokumentation ...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenster</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimieren</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>&amp;Gehe zu</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Lesezeichen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
</context>
<context>
    <name>OpenPagesWidget</name>
    <message>
        <source>Close %1</source>
        <translation>Schließe %1</translation>
    </message>
    <message>
        <source>Close All Except %1</source>
        <translation>Alle außer %1 schließen</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Use custom settings</source>
        <translation>Benutzerdefinierte Einstellungen verwenden</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>Schriftart:</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Browser</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Anwendung</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentation</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>Aktuelle Seite</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>Voreinstellung wiederherstellen</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Startseite</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>Zu Beginn:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Startseite zeigen</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Leere Seite zeigen</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>Reiter aus letzter Sitzung zeigen</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>Leere Seite</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Show tabs for each individual page</source>
        <translation>Reiter für jede einzelne Seite anzeigen</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>Debugging Remote Control</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>Empfangenes Kommando: %1 : %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>&amp;Link-Adresse kopieren</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Link in neuem Reiter öffnen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles markieren</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Ohne Titel)</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Neuer &amp;Reiter</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Reiter &amp;schließen</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Andere Reiter schließen</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>Lesezeichen für diese Seite hinzufügen ...</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>Wählen Sie ein Thema für &lt;b&gt;%1&lt;/b&gt;:</translation>
    </message>
    <message>
        <source>Choose Topic</source>
        <translation>Thema wählen</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>&amp;Themen</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Anzeigen</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
</context>
</TS>
